# BillingAddressAttributes


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**address_1** | **str** | The first address line. | [optional] 
**address_2** | **str, none_type** | The second address line. | [optional] 
**city** | **str, none_type** | The city name. | [optional] 
**country** | **str** | ISO 3166-1 two-letter country code. | [optional] 
**locality** | **str, none_type** | Other locality. | [optional] 
**postal_code** | **str** | Postal code (ZIP code for US addresses). | [optional] 
**state** | **str, none_type** | The state or province name. | [optional] 
**customer_id** | **str** |  | [optional] [readonly] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


